
import React, { useState } from "react"
import { md, pki } from "node-forge"
import classNames from "classnames"
import GeneratePrivateKey from "./GeneratePrivateKey.jsx"
import KeyUpload from "./KeyUpload.jsx"
import P12Download from "./P12Download.jsx"

const P12Dialog = ({csrfToken, certPemElements}) => {

  const [privateKey, setPrivateKey] = useState(null)
  const [password, setPassword] = useState(null)

  const handleKeyUpload = (key, password) => {
      setPrivateKey(key)
      setPassword(password)
  }

  const certPems = Array.from(certPemElements).map(x => x.textContent)

  return (<>
      <div className="card m-2">
        <h3 className="card-header">Create PKCS 12</h3>
        <div className="card-body">
          <KeyUpload
              onKeyUpload={(key, password) => handleKeyUpload(key, password)}
          />
          { (certPems.length && privateKey) && <>
            <hr />
            <P12Download certPems={certPems} password={password}
                         privateKey={privateKey} />
          </>}
        </div>
      </div>
  </>)
}

export default P12Dialog
